@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Activity {
-    client: Client,
+    pub client: Client,
 }
 
 impl Activity {
@@ -31,21 +31,15 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Event>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/events?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/events?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -113,25 +107,19 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Event>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/networks/{}/{}/events?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -189,33 +177,27 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Thread>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if all {
-            query_args.push(format!("all={}", all));
+            query_args.push(("all".to_string(), all.to_string()));
         }
         if let Some(date) = before {
-            query_args.push(format!("before={}", &date.to_rfc3339()));
+            query_args.push(("before".to_string(), date.to_rfc3339()));
         }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if participating {
-            query_args.push(format!("participating={}", participating));
+            query_args.push(("participating".to_string(), participating.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/notifications?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/notifications?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -238,27 +220,21 @@ impl Activity {
         since: Option<chrono::DateTime<chrono::Utc>>,
         before: Option<chrono::DateTime<chrono::Utc>>,
     ) -> Result<Vec<crate::types::Thread>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if all {
-            query_args.push(format!("all={}", all));
+            query_args.push(("all".to_string(), all.to_string()));
         }
         if let Some(date) = before {
-            query_args.push(format!("before={}", &date.to_rfc3339()));
+            query_args.push(("before".to_string(), date.to_rfc3339()));
         }
         if participating {
-            query_args.push(format!("participating={}", participating));
+            query_args.push(("participating".to_string(), participating.to_string()));
         }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/notifications?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/notifications?{}", query_);
 
         self.client.get_all_pages(&url, None).await
     }
@@ -278,10 +254,7 @@ impl Activity {
     ) -> Result<crate::types::Error> {
         let url = "/notifications".to_string();
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -384,10 +357,7 @@ impl Activity {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -434,24 +404,18 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Event>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/events?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -500,25 +464,19 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Event>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/events?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -580,37 +538,31 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Thread>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if all {
-            query_args.push(format!("all={}", all));
+            query_args.push(("all".to_string(), all.to_string()));
         }
         if let Some(date) = before {
-            query_args.push(format!("before={}", &date.to_rfc3339()));
+            query_args.push(("before".to_string(), date.to_rfc3339()));
         }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if participating {
-            query_args.push(format!("participating={}", participating));
+            query_args.push(("participating".to_string(), participating.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/notifications?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -636,31 +588,25 @@ impl Activity {
         since: Option<chrono::DateTime<chrono::Utc>>,
         before: Option<chrono::DateTime<chrono::Utc>>,
     ) -> Result<Vec<crate::types::Thread>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if all {
-            query_args.push(format!("all={}", all));
+            query_args.push(("all".to_string(), all.to_string()));
         }
         if let Some(date) = before {
-            query_args.push(format!("before={}", &date.to_rfc3339()));
+            query_args.push(("before".to_string(), date.to_rfc3339()));
         }
         if participating {
-            query_args.push(format!("participating={}", participating));
+            query_args.push(("participating".to_string(), participating.to_string()));
         }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/notifications?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -693,10 +639,7 @@ impl Activity {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -725,25 +668,19 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::ActivityListStargazersRepoResponseAnyOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/stargazers?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -772,25 +709,19 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::SimpleUser>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/subscribers?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -876,10 +807,7 @@ impl Activity {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -934,23 +862,21 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Repository>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
-        let url = format!("/user/starred?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/user/starred?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -973,17 +899,15 @@ impl Activity {
         sort: crate::types::Sort,
         direction: crate::types::Order,
     ) -> Result<Vec<crate::types::Repository>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
         }
-        let url = format!("/user/starred?{}", query);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/user/starred?{}", query_);
 
         self.client.get_all_pages(&url, None).await
     }
@@ -1083,21 +1007,15 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::MinimalRepository>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/user/subscriptions?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/user/subscriptions?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -1141,24 +1059,18 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Event>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/events?{}",
             crate::progenitor_support::encode_path(&username.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1210,25 +1122,19 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Event>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/events/orgs/{}?{}",
             crate::progenitor_support::encode_path(&username.to_string()),
             crate::progenitor_support::encode_path(&org.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1280,24 +1186,18 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Event>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/events/public?{}",
             crate::progenitor_support::encode_path(&username.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1347,24 +1247,18 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Event>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/received_events?{}",
             crate::progenitor_support::encode_path(&username.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1414,24 +1308,18 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Event>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/received_events/public?{}",
             crate::progenitor_support::encode_path(&username.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1489,26 +1377,24 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::ActivityListReposStarredByUserResponseAnyOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/starred?{}",
             crate::progenitor_support::encode_path(&username.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1535,24 +1421,18 @@ impl Activity {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::MinimalRepository>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/subscriptions?{}",
             crate::progenitor_support::encode_path(&username.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
