@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Apps {
-    client: Client,
+    pub client: Client,
 }
 
 impl Apps {
@@ -86,10 +86,7 @@ impl Apps {
     ) -> Result<crate::types::WebhookConfig> {
         let url = "/app/hook/config".to_string();
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -114,21 +111,15 @@ impl Apps {
         per_page: i64,
         cursor: &str,
     ) -> Result<Vec<crate::types::HookDeliveryItem>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !cursor.is_empty() {
-            query_args.push(format!("cursor={}", cursor));
+            query_args.push(("cursor".to_string(), cursor.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/app/hook/deliveries?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/app/hook/deliveries?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -150,18 +141,12 @@ impl Apps {
         &self,
         cursor: &str,
     ) -> Result<Vec<crate::types::HookDeliveryItem>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !cursor.is_empty() {
-            query_args.push(format!("cursor={}", cursor));
+            query_args.push(("cursor".to_string(), cursor.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/app/hook/deliveries?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/app/hook/deliveries?{}", query_);
 
         self.client.get_all_pages(&url, None).await
     }
@@ -242,27 +227,21 @@ impl Apps {
         since: Option<chrono::DateTime<chrono::Utc>>,
         outdated: &str,
     ) -> Result<Vec<crate::types::Installation>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !outdated.is_empty() {
-            query_args.push(format!("outdated={}", outdated));
+            query_args.push(("outdated".to_string(), outdated.to_string()));
         }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/app/installations?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/app/installations?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -285,21 +264,15 @@ impl Apps {
         since: Option<chrono::DateTime<chrono::Utc>>,
         outdated: &str,
     ) -> Result<Vec<crate::types::Installation>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !outdated.is_empty() {
-            query_args.push(format!("outdated={}", outdated));
+            query_args.push(("outdated".to_string(), outdated.to_string()));
         }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/app/installations?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/app/installations?{}", query_);
 
         self.client.get_all_pages(&url, None).await
     }
@@ -384,7 +357,7 @@ impl Apps {
         self.client
             .post_media(
                 &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
+                Some(reqwest::Body::from(serde_json::to_vec(body)?)),
                 crate::utils::MediaType::Json,
                 crate::auth::AuthenticationConstraint::JWT,
             )
@@ -464,10 +437,7 @@ impl Apps {
         );
 
         self.client
-            .delete(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .delete(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -527,10 +497,7 @@ impl Apps {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -558,10 +525,7 @@ impl Apps {
         );
 
         self.client
-            .delete(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .delete(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -589,10 +553,7 @@ impl Apps {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -620,10 +581,7 @@ impl Apps {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -762,21 +720,15 @@ impl Apps {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::AppsListInstallationReposResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/installation/repositories?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/installation/repositories?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -847,21 +799,15 @@ impl Apps {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::MarketplaceListingPlan>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/marketplace_listing/plans?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/marketplace_listing/plans?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -913,26 +859,24 @@ impl Apps {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::MarketplacePurchaseData>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/marketplace_listing/plans/{}/accounts?{}",
             crate::progenitor_support::encode_path(&plan_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -957,20 +901,18 @@ impl Apps {
         sort: crate::types::Sort,
         direction: crate::types::Order,
     ) -> Result<Vec<crate::types::MarketplacePurchaseData>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
         }
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/marketplace_listing/plans/{}/accounts?{}",
             crate::progenitor_support::encode_path(&plan_id.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -1024,21 +966,15 @@ impl Apps {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::MarketplaceListingPlan>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/marketplace_listing/stubbed/plans?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/marketplace_listing/stubbed/plans?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -1092,26 +1028,24 @@ impl Apps {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::MarketplacePurchaseData>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/marketplace_listing/stubbed/plans/{}/accounts?{}",
             crate::progenitor_support::encode_path(&plan_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1136,20 +1070,18 @@ impl Apps {
         sort: crate::types::Sort,
         direction: crate::types::Order,
     ) -> Result<Vec<crate::types::MarketplacePurchaseData>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
         }
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/marketplace_listing/stubbed/plans/{}/accounts?{}",
             crate::progenitor_support::encode_path(&plan_id.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -1213,10 +1145,7 @@ impl Apps {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1275,21 +1204,15 @@ impl Apps {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::AppsListInstallationsResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/user/installations?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/user/installations?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -1321,24 +1244,18 @@ impl Apps {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::AppsListInstallationReposResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/user/installations/{}/repositories?{}",
             crate::progenitor_support::encode_path(&installation_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1423,21 +1340,15 @@ impl Apps {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::UserMarketplacePurchase>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/user/marketplace_purchases?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/user/marketplace_purchases?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -1479,21 +1390,15 @@ impl Apps {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::UserMarketplacePurchase>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/user/marketplace_purchases/stubbed?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/user/marketplace_purchases/stubbed?{}", query_);
 
         self.client.get(&url, None).await
     }
