@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct CodeScanning {
-    client: Client,
+    pub client: Client,
 }
 
 impl CodeScanning {
@@ -51,35 +51,31 @@ impl CodeScanning {
         ref_: &str,
         state: crate::types::CodeScanningAlertState,
     ) -> Result<Vec<crate::types::CodeScanningAlertItems>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !ref_.is_empty() {
-            query_args.push(format!("ref={}", ref_));
+            query_args.push(("ref".to_string(), ref_.to_string()));
+        }
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
         }
-        query_args.push(format!("state={}", state));
         if !tool_guid.is_empty() {
-            query_args.push(format!("tool_guid={}", tool_guid));
+            query_args.push(("tool_guid".to_string(), tool_guid.to_string()));
         }
         if !tool_name.is_empty() {
-            query_args.push(format!("tool_name={}", tool_name));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("tool_name".to_string(), tool_name.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/code-scanning/alerts?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -113,29 +109,25 @@ impl CodeScanning {
         ref_: &str,
         state: crate::types::CodeScanningAlertState,
     ) -> Result<Vec<crate::types::CodeScanningAlertItems>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !ref_.is_empty() {
-            query_args.push(format!("ref={}", ref_));
+            query_args.push(("ref".to_string(), ref_.to_string()));
+        }
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
         }
-        query_args.push(format!("state={}", state));
         if !tool_guid.is_empty() {
-            query_args.push(format!("tool_guid={}", tool_guid));
+            query_args.push(("tool_guid".to_string(), tool_guid.to_string()));
         }
         if !tool_name.is_empty() {
-            query_args.push(format!("tool_name={}", tool_name));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("tool_name".to_string(), tool_name.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/code-scanning/alerts?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -205,10 +197,7 @@ impl CodeScanning {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -239,29 +228,23 @@ impl CodeScanning {
         per_page: i64,
         ref_: &str,
     ) -> Result<Vec<crate::types::CodeScanningAlertInstance>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !ref_.is_empty() {
-            query_args.push(format!("ref={}", ref_));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("ref".to_string(), ref_.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/code-scanning/alerts/{}/instances?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&alert_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -285,23 +268,17 @@ impl CodeScanning {
         alert_number: i64,
         ref_: &str,
     ) -> Result<Vec<crate::types::CodeScanningAlertInstance>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !ref_.is_empty() {
-            query_args.push(format!("ref={}", ref_));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("ref".to_string(), ref_.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/code-scanning/alerts/{}/instances?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&alert_number.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -353,37 +330,31 @@ impl CodeScanning {
         ref_: &str,
         sarif_id: &str,
     ) -> Result<Vec<crate::types::CodeScanningAnalysis>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !ref_.is_empty() {
-            query_args.push(format!("ref={}", ref_));
+            query_args.push(("ref".to_string(), ref_.to_string()));
         }
         if !sarif_id.is_empty() {
-            query_args.push(format!("sarif_id={}", sarif_id));
+            query_args.push(("sarif_id".to_string(), sarif_id.to_string()));
         }
         if !tool_guid.is_empty() {
-            query_args.push(format!("tool_guid={}", tool_guid));
+            query_args.push(("tool_guid".to_string(), tool_guid.to_string()));
         }
         if !tool_name.is_empty() {
-            query_args.push(format!("tool_name={}", tool_name));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("tool_name".to_string(), tool_name.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/code-scanning/analyses?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -424,31 +395,25 @@ impl CodeScanning {
         ref_: &str,
         sarif_id: &str,
     ) -> Result<Vec<crate::types::CodeScanningAnalysis>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !ref_.is_empty() {
-            query_args.push(format!("ref={}", ref_));
+            query_args.push(("ref".to_string(), ref_.to_string()));
         }
         if !sarif_id.is_empty() {
-            query_args.push(format!("sarif_id={}", sarif_id));
+            query_args.push(("sarif_id".to_string(), sarif_id.to_string()));
         }
         if !tool_guid.is_empty() {
-            query_args.push(format!("tool_guid={}", tool_guid));
+            query_args.push(("tool_guid".to_string(), tool_guid.to_string()));
         }
         if !tool_name.is_empty() {
-            query_args.push(format!("tool_name={}", tool_name));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("tool_name".to_string(), tool_name.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/code-scanning/analyses?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -591,23 +556,17 @@ impl CodeScanning {
         analysis_id: i64,
         confirm_delete: &str,
     ) -> Result<crate::types::AnalysisDeletion> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !confirm_delete.is_empty() {
-            query_args.push(format!("confirm_delete={}", confirm_delete));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("confirm_delete".to_string(), confirm_delete.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/code-scanning/analyses/{}?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&analysis_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
@@ -656,10 +615,7 @@ impl CodeScanning {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
