@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Meta {
-    client: Client,
+    pub client: Client,
 }
 
 impl Meta {
@@ -57,18 +57,12 @@ impl Meta {
      * * `s: &str` -- The words to show in Octocat's speech bubble.
      */
     pub async fn get_octocat(&self, s: &str) -> Result<String> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !s.is_empty() {
-            query_args.push(format!("s={}", s));
+            query_args.push(("s".to_string(), s.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/octocat?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/octocat?{}", query_);
 
         self.client.get(&url, None).await
     }
