@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Migrations {
-    client: Client,
+    pub client: Client,
 }
 
 impl Migrations {
@@ -35,27 +35,21 @@ impl Migrations {
         page: i64,
         exclude: &[String],
     ) -> Result<Vec<crate::types::Migration>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !exclude.is_empty() {
-            query_args.push(format!("exclude={}", exclude.join(" ")));
+            query_args.push(("exclude".to_string(), exclude.join(" ")));
         }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/migrations?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -77,21 +71,15 @@ impl Migrations {
         org: &str,
         exclude: &[String],
     ) -> Result<Vec<crate::types::Migration>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !exclude.is_empty() {
-            query_args.push(format!("exclude={}", exclude.join(" ")));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("exclude".to_string(), exclude.join(" ")));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/migrations?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -121,10 +109,7 @@ impl Migrations {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -156,22 +141,16 @@ impl Migrations {
         migration_id: i64,
         exclude: &[String],
     ) -> Result<crate::types::Migration> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !exclude.is_empty() {
-            query_args.push(format!("exclude={}", exclude.join(" ")));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("exclude".to_string(), exclude.join(" ")));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/migrations/{}?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&migration_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -279,25 +258,19 @@ impl Migrations {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::MinimalRepository>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/migrations/{}/repositories?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&migration_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -412,10 +385,7 @@ impl Migrations {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -471,10 +441,7 @@ impl Migrations {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -501,22 +468,16 @@ impl Migrations {
         repo: &str,
         since: i64,
     ) -> Result<Vec<crate::types::PorterAuthor>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if since > 0 {
-            query_args.push(format!("since={}", since));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("since".to_string(), since.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/import/authors?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -541,22 +502,16 @@ impl Migrations {
         repo: &str,
         since: i64,
     ) -> Result<Vec<crate::types::PorterAuthor>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if since > 0 {
-            query_args.push(format!("since={}", since));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("since".to_string(), since.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/import/authors?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -592,10 +547,7 @@ impl Migrations {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -679,10 +631,7 @@ impl Migrations {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -705,21 +654,15 @@ impl Migrations {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Migration>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/user/migrations?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/user/migrations?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -755,10 +698,7 @@ impl Migrations {
     ) -> Result<crate::types::Migration> {
         let url = "/user/migrations".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -788,21 +728,15 @@ impl Migrations {
         migration_id: i64,
         exclude: &[String],
     ) -> Result<crate::types::Migration> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !exclude.is_empty() {
-            query_args.push(format!("exclude={}", exclude.join(" ")));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("exclude".to_string(), exclude.join(" ")));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/user/migrations/{}?{}",
             crate::progenitor_support::encode_path(&migration_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -921,24 +855,18 @@ impl Migrations {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::MinimalRepository>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/user/migrations/{}/repositories?{}",
             crate::progenitor_support::encode_path(&migration_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
